summaryrefslogtreecommitdiffstats
path: root/kttsd/libkttsd/pluginconf.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kttsd/libkttsd/pluginconf.cpp')
-rw-r--r--kttsd/libkttsd/pluginconf.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/kttsd/libkttsd/pluginconf.cpp b/kttsd/libkttsd/pluginconf.cpp
index 0674057..b076729 100644
--- a/kttsd/libkttsd/pluginconf.cpp
+++ b/kttsd/libkttsd/pluginconf.cpp
@@ -62,11 +62,11 @@ PlugInConf::~PlugInConf(){
* loaded, so it not necessary to call it in your constructor.
* The plugin should read its configuration from the specified group
* in the specified config file.
* @param config Pointer to a KConfig object.
* @param configGroup Call config->setGroup with this argument before
* loading your configuration.
*/
-void PlugInConf::load(KConfig* /*config*/, const TQString& /*configGroup*/){
+void PlugInConf::load(TDEConfig* /*config*/, const TQString& /*configGroup*/){
kdDebug() << "PlugInConf::load: Running" << endl;
}
@@ -76,11 +76,11 @@ void PlugInConf::load(KConfig* /*config*/, const TQString& /*configGroup*/){
* configuration is stored. The method is called when the user clicks "Apply"
* or "Ok". The plugin should save its configuration in the specified
* group of the specified config file.
* @param config Pointer to a KConfig object.
* @param configGroup Call config->setGroup with this argument before
* saving your configuration.
*/
-void PlugInConf::save(KConfig* /*config*/, const TQString& /*configGroup*/){
+void PlugInConf::save(TDEConfig* /*config*/, const TQString& /*configGroup*/){
kdDebug() << "PlugInConf::save: Running" << endl;
}
@@ -62,11 +62,11 @@ PlugInConf::~PlugInConf(){
* The plugin should read its configuration from the specified group
* in the specified config file.
-* @param config Pointer to a KConfig object.
+* @param config Pointer to a TDEConfig object.
* @param configGroup Call config->setGroup with this argument before
* loading your configuration.
@@ -76,11 +76,11 @@ void PlugInConf::load(KConfig* /*config*/, const TQString& /*configGroup*/){
* or "Ok". The plugin should save its configuration in the specified
* group of the specified config file.
-* @param config Pointer to a KConfig object.
+* @param config Pointer to a TDEConfig object.
* @param configGroup Call config->setGroup with this argument before
* saving your configuration.